Crate loess_rust_opaque

Crate loess_rust_opaque 

Additional grammar tokens representing the stable Rust programming language, closely following The Rust Reference.

Corrections in that regard are not automatically considered breaking changes, unless they became necessary due to a change in Rust and reduce what is considered valid.

Breaking changes to the API are considered breaking as normal.

Note that unstable grammar is accidentally accepted in some cases.
Ceasing to accept unstable grammar is not by itself considered a breaking change for Loess.

Structs

Expression
Expression
ExpressionExceptStructExpression
Expression except StructExpression
Pattern
Pattern
SimplePath
SimplePath
Statement
Statement